@@ -288,9 +288,15 @@ class AssetServiceClient(object):
     ):
         """
         Exports assets with time and resource types to a given Cloud Storage
-        location. The output format is newline-delimited JSON. This API
-        implements the ``google.longrunning.Operation`` API allowing you to keep
-        track of the export.
+        location/BigQuery table. For Cloud Storage location destinations, the
+        output format is newline-delimited JSON. Each line represents a
+        ``google.cloud.asset.v1.Asset`` in the JSON format; for BigQuery table
+        destinations, the output table stores the fields in asset proto as
+        columns. This API implements the ``google.longrunning.Operation`` API ,
+        which allows you to keep track of the export. We recommend intervals of
+        at least 2 seconds with exponential retry to poll the export operation
+        result. For regular-size resource parent, the export operation usually
+        finishes within 5 minutes.
 
         Example:
             >>> from google.cloud import asset_v1
@@ -320,7 +326,7 @@ class AssetServiceClient(object):
                 "projects/my-project-id"), or a project number (such as "projects/12345"),
                 or a folder number (such as "folders/123").
             output_config (Union[dict, ~google.cloud.asset_v1.types.OutputConfig]): Required. Output configuration indicating where the results will be output
-                to. All results will be in newline delimited JSON format.
+                to.
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.asset_v1.types.OutputConfig`
@@ -332,7 +338,7 @@ class AssetServiceClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.asset_v1.types.Timestamp`
-            asset_types (list[str]): A list of asset types of which to take a snapshot for. For example:
+            asset_types (list[str]): A list of asset types of which to take a snapshot for. Example:
                 "compute.googleapis.com/Disk". If specified, only matching assets will
                 be returned. See `Introduction to Cloud Asset
                 Inventory <https://cloud.google.com/asset-inventory/docs/overview>`__
@@ -411,11 +417,11 @@ class AssetServiceClient(object):
     ):
         """
         Batch gets the update history of assets that overlap a time window.
-        For RESOURCE content, this API outputs history with asset in both
-        non-delete or deleted status. For IAM_POLICY content, this API outputs
-        history when the asset and its attached IAM POLICY both exist. This can
-        create gaps in the output history. If a specified asset does not exist,
-        this API returns an INVALID_ARGUMENT error.
+        For IAM_POLICY content, this API outputs history when the asset and its
+        attached IAM POLICY both exist. This can create gaps in the output
+        history. Otherwise, this API outputs history with asset in both
+        non-delete or deleted status. If a specified asset does not exist, this
+        API returns an INVALID_ARGUMENT error.
 
         Example:
             >>> from google.cloud import asset_v1
@@ -431,13 +437,11 @@ class AssetServiceClient(object):
             parent (str): Required. The relative name of the root asset. It can only be an
                 organization number (such as "organizations/123"), a project ID (such as
                 "projects/my-project-id")", or a project number (such as "projects/12345").
-            asset_names (list[str]): A list of the full names of the assets. For example:
+            asset_names (list[str]): A list of the full names of the assets. See:
+                https://cloud.google.com/asset-inventory/docs/resource-name-format
+                Example:
+
                 ``//compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1``.
-                See `Resource
-                Names <https://cloud.google.com/apis/design/resource_names#full_resource_name>`__
-                and `Resource Name
-                Format <https://cloud.google.com/asset-inventory/docs/resource-name-format>`__
-                for more info.
 
                 The request becomes a no-op if the asset name list is empty, and the max
                 size of the asset name list is 100 in one request.
