@@ -133,9 +133,15 @@ class AssetServiceGrpcTransport(object):
         """Return the gRPC stub for :meth:`AssetServiceClient.export_assets`.
 
         Exports assets with time and resource types to a given Cloud Storage
-        location. The output format is newline-delimited JSON. This API
-        implements the ``google.longrunning.Operation`` API allowing you to keep
-        track of the export.
+        location/BigQuery table. For Cloud Storage location destinations, the
+        output format is newline-delimited JSON. Each line represents a
+        ``google.cloud.asset.v1.Asset`` in the JSON format; for BigQuery table
+        destinations, the output table stores the fields in asset proto as
+        columns. This API implements the ``google.longrunning.Operation`` API ,
+        which allows you to keep track of the export. We recommend intervals of
+        at least 2 seconds with exponential retry to poll the export operation
+        result. For regular-size resource parent, the export operation usually
+        finishes within 5 minutes.
 
         Returns:
             Callable: A callable which accepts the appropriate
@@ -149,11 +155,11 @@ class AssetServiceGrpcTransport(object):
         """Return the gRPC stub for :meth:`AssetServiceClient.batch_get_assets_history`.
 
         Batch gets the update history of assets that overlap a time window.
-        For RESOURCE content, this API outputs history with asset in both
-        non-delete or deleted status. For IAM_POLICY content, this API outputs
-        history when the asset and its attached IAM POLICY both exist. This can
-        create gaps in the output history. If a specified asset does not exist,
-        this API returns an INVALID_ARGUMENT error.
+        For IAM_POLICY content, this API outputs history when the asset and its
+        attached IAM POLICY both exist. This can create gaps in the output
+        history. Otherwise, this API outputs history with asset in both
+        non-delete or deleted status. If a specified asset does not exist, this
+        API returns an INVALID_ARGUMENT error.
 
         Returns:
             Callable: A callable which accepts the appropriate
